//  //
//  ###  ##### #   #               -= Confix Library =-                  //
// #   # #     ## ## Demo.cpp - Confix demonstration application         //
// #     ####   ###                                                      //
// #     #      ###  Representation of a configuration file variable     //
// #   # #     ## ##                                                     //
//  ###  #     #   # R1             (C)2002 Markus Ewald -> License.txt  //
//  //
#include <iostream>
#include <typeinfo>

#include "Confix/Confix.h"
using namespace CFX;
using namespace std;

// ####################################################################### //
// # main()                                                              # //
// ####################################################################### //
/** Program entry point
*/
int main(void) {
  const char pszConfigFile[] = "# Simple configuration file\n"
                               "Test = 123          // With comments\n"
                               "String = Hello"
                               "\n"
                               "[Section        ]\n"
                               "String = World\n"
                               "Test = 123.456\n";
  
  try {
    CFX::CConfigFile CFG(pszConfigFile);

    // Reading variables
    cout << "Global entries: " << CFG.getSection(0).getNumVariables() << endl;
    cout << "Value of Test: " << CFG.getSection(0).getVariable("Test").getLong() << endl;
    
    // Changing
    CFG.getSection(0).getVariable("Test") = 456;
    CFG.getSection("Section").setName("NewName");

    // Removing / adding
    CFG.getSection(0).removeVariable("String");
    CFG.getSection("NewName").addVariable(CConfigVariable("String = Hello"));

    // Show changed contents
    cout << "========================================" << endl;
    cout << CFG.getContents() << endl;
  }
  catch(const std::exception &e) {
    cout << "Exception: " << e.what() << 
            " (" << typeid(e).name() << ")" << endl;
    throw;
  }

  return 0;
}
